<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="handymanTypeTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { fetchList, delObj } from '@/api/product/handymantype'
import TableForm from './handymantype-form'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'
import { remote } from '../../../api/admin/dict'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      dataListLoading: false,
      addOrUpdateVisible: false,
      isShowQuery: false,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/handymanType/upload'
      },
      dateTimeFilters: {},
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'handymanNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            width: '140',
            prop: 'handymanNo',
            label: '人工编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text',
            render: { fun: this.addOrUpdateHandle }
          },
          {
            width: '140',
            prop: 'handymanName',
            label: '人工名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            prop: 'workstationName',
            label: '工作站',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            prop: 'standardHourWage',
            label: '工时系数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '140',
            prop: 'comment',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },

          {
            width: '140',
            prop: 'loadType',
            label: '工作量类型',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatLoadType,
            optList: () => {
              return this.loadTypeOptions
            }
          },
          {
            width: '140',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.formatUnit,
            optList: () => {
              return this.unitOptions
            }
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      wageTypeOptions: [],
      loadTypeOptions: [],
      unitOptions: []
    }
  },
  components: {
    TableForm,
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    this.initOptions()
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.handymanTypeTable.getDataList()
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除人工名称为：' + row.handymanName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    // 获取数据字典-工资类型
    initOptions() {
      remote('wage_type').then((response) => {
        if (response.data.code === 0) {
          this.wageTypeOptions = response.data.data
        }
      })
      remote('load_type').then((response) => {
        if (response.data.code === 0) {
          this.loadTypeOptions = response.data.data
        }
      })
      remote('workload_unit').then((response) => {
        if (response.data.code === 0) {
          this.unitOptions = response.data.data
        }
      })
    },
    // 表格字段格式化
    formatWageType(row, column, cellValue) {
      for (let i = 0, len = this.wageTypeOptions.length; i < len; i++) {
        if (cellValue == this.wageTypeOptions[i].value) {
          return this.wageTypeOptions[i].label
        }
      }
    },
    formatLoadType(row, column, cellValue) {
      for (let i = 0, len = this.loadTypeOptions.length; i < len; i++) {
        if (cellValue == this.loadTypeOptions[i].value) {
          return this.loadTypeOptions[i].label
        }
      }
    },
    formatUnit(row, column, cellValue) {
      for (let i = 0, len = this.unitOptions.length; i < len; i++) {
        if (cellValue == this.unitOptions[i].value) {
          return this.unitOptions[i].label
        }
      }
    }
  }
}
</script>
